EdgeDetectorPlatform class abstract

Platform specific implementation of EdgeDetector.

Inheritance
  • Object
  • PlatformInterface
  • EdgeDetectorPlatform
Implementers

Constructors

EdgeDetectorPlatform()
Constructs a EdgeDetectorPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectEdges(File imageFile) Future<Edges?>
Detects edges of given imageFile
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EdgeDetectorPlatform
The default instance of EdgeDetectorPlatform to use.
getter/setter pair